#!/usr/bin/env python

#===============================================================================
#   renamer.py      |   version 1.0 |   FreeBSD License |   2013-04-02
#   James Hendrie   |   hendrie dot james at gmail dot com
#===============================================================================

import sys, shutil

##  Our default verbosity value.
defaultVerbosity = True

def print_help():
    """
    Function to print help text.
    """
    helpStr="""
This script provides an easy way to rename part of a filename.  Primarily, it's
intended to do mass filename extension changes, or stuff like that.

Usage:
    renamer [verbosity] "OLD_STRING" "NEW_STRING" [file(s)]

    Arguments:
        -v or --verbose:    Verbose output (default)
        -s or --silent:     Silence output
        --version:          Print version and author info
        -h or --help:       Print this help text

    Examples:
        renamer .m4v .mp4 *
            Rename all files with .m4v extension so that they end with .mp4
        renamer -v ".m4v" ".mp4" *
            Same as above, but the script will be verbose about it

Obviously, you should display some measure of caution when using this script.

    """
    print(helpStr)


def print_version():
    """
    Function to print version and author info
    """
    print("renamer.py, version 1.0, 2013-04-02")
    print("Written by James Hendrie <hendrie dot james at gmail dot com>")


def handle_args(argsList):
    """
    Function to handle arguments
    """

    ##  We look to our defaultVerbosity variable for our value here
    verbose = defaultVerbosity

    ##  Check for specific arguments and behave appropriately if found
    for arg in argsList:
        if arg == '--help' or arg == '-h':
            print_help()
            sys.exit()
        elif arg == "--version":
            print_version()
            sys.exit()
        elif arg == "--verbose" or arg == "-v":
            verbose = True
            argsList.remove(arg)
        elif arg == "--silent" or arg == "-s":
            verbose = False
            argsList.remove(arg)

    ##  Here, we re-check to make sure there are the correct number of args
    if (len(argsList) < 3):
        print("Error:  Too few arguments")
        print_help()
        sys.exit()

    ##  Turn our remaining arguments into something useful
    oldStr = argsList[0]
    newStr = argsList[1]
    fileList = argsList[2:]

    return oldStr, newStr, fileList, verbose

def mover(f, oldStr, newStr, verbose):
    """
    The function that does the actual moving of the files
    """

    ##  For every instance where the first pattern is found in the filename
    if (oldStr in f):
        ##  Replace the old pattern with the new patter
        newName = f.replace(oldStr, newStr, -1)

        ##  If verbosity is on, tell the user what's up
        if (verbose == True):
            print("%s -> %s" % (f, newName))

        ##  Move the original file to its new name
        shutil.move(f, newName)


def main():
    """
    Main function
    """

    ##  If we have fewer than 4 arguments (including the script), bail out
    if (len(sys.argv) < 4):
        print("Error:  Too few arguments.")
        print_help()
    else:
        oldStr, newStr, fileList, verbose = handle_args(sys.argv[1:])
        for f in fileList:
            mover(f, oldStr, newStr, verbose)



if __name__ == "__main__":
    main()
